==> jc-1.4.0.tar.gz: gnu/xml/xpath/NodeTypeTest.h <==
// public final class gnu.xml.xpath.NodeTypeTest

// class file dependencies
// @dep_class 13066c0bc3c76e17 gnu_xml_xpath_NodeTypeTest
// @dep_class d99963ba20fa6197 gnu_xml_xpath_Test
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Test

#include "gnu/xml/xpath/Test.h"

#ifndef _JC_gnu_xml_xpath_NodeTypeTest_H_
#define _JC_gnu_xml_xpath_NodeTypeTest_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Test$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_NodeTypeTest$sub_refs	_jc_gnu_xml_xpath_NodeTypeTest$sub_refs;
typedef struct _jc_gnu_xml_xpath_NodeTypeTest$sub_nonrefs	_jc_gnu_xml_xpath_NodeTypeTest$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_NodeTypeTest$refs	_jc_gnu_xml_xpath_NodeTypeTest$refs;
typedef struct _jc_gnu_xml_xpath_NodeTypeTest$nonrefs	_jc_gnu_xml_xpath_NodeTypeTest$nonrefs;
typedef struct _jc_gnu_xml_xpath_NodeTypeTest$object	_jc_gnu_xml_xpath_NodeTypeTest$object;

typedef const struct _jc_gnu_xml_xpath_NodeTypeTest$vmethods	_jc_gnu_xml_xpath_NodeTypeTest$vmethods;
typedef const struct _jc_gnu_xml_xpath_NodeTypeTest$vtable	_jc_gnu_xml_xpath_NodeTypeTest$vtable;
typedef const struct _jc_gnu_xml_xpath_NodeTypeTest$vtype	_jc_gnu_xml_xpath_NodeTypeTest$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_NodeTypeTest$method$_init$919dbf5c26f3754c(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *, jshort);
extern void _jc_gnu_xml_xpath_NodeTypeTest$method$_init$f5cdf9de5128930c(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *, jshort, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Test$object *_jc_gnu_xml_xpath_NodeTypeTest$method$clone$73a8d2a4d673dd95(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_NodeTypeTest$method$getData$bbc608c204d64215(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *);
extern jshort _jc_gnu_xml_xpath_NodeTypeTest$method$getNodeType$130bb679261c54d5(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *);
extern jboolean _jc_gnu_xml_xpath_NodeTypeTest$method$matches$528a77e426fd27f8(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *, struct _jc_object *, jint, jint);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_NodeTypeTest$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_NodeTypeTest$method_info$clone$73a8d2a4d673dd95;
extern _jc_method _jc_gnu_xml_xpath_NodeTypeTest$method_info$getData$bbc608c204d64215;
extern _jc_method _jc_gnu_xml_xpath_NodeTypeTest$method_info$getNodeType$130bb679261c54d5;
extern _jc_method _jc_gnu_xml_xpath_NodeTypeTest$method_info$matches$528a77e426fd27f8;
extern _jc_method _jc_gnu_xml_xpath_NodeTypeTest$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_NodeTypeTest$vmethods {
	struct _jc_gnu_xml_xpath_Test$object	*(*clone$73a8d2a4d673dd95)(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getData$bbc608c204d64215)(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *);
	jshort	(*getNodeType$130bb679261c54d5)(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *);
	jboolean	(*matches$528a77e426fd27f8)(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *, struct _jc_object *, jint, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *);
};

// Vtable
struct _jc_gnu_xml_xpath_NodeTypeTest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Test$vmethods	gnu_xml_xpath_Test;
	_jc_gnu_xml_xpath_NodeTypeTest$vmethods	gnu_xml_xpath_NodeTypeTest;
};

// Vtype
struct _jc_gnu_xml_xpath_NodeTypeTest$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_NodeTypeTest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_NodeTypeTest$sub_refs {
	struct _jc_java_lang_String$object	*data;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_NodeTypeTest$refs {
    _jc_gnu_xml_xpath_NodeTypeTest$sub_refs	gnu_xml_xpath_NodeTypeTest;
    _jc_gnu_xml_xpath_Test$sub_refs	gnu_xml_xpath_Test;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_NodeTypeTest$sub_nonrefs {
	jshort	type;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_NodeTypeTest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Test$sub_nonrefs	gnu_xml_xpath_Test;
    _jc_gnu_xml_xpath_NodeTypeTest$sub_nonrefs	gnu_xml_xpath_NodeTypeTest;
};

// Object instance structure
struct _jc_gnu_xml_xpath_NodeTypeTest$object {
	_jc_gnu_xml_xpath_NodeTypeTest$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_NodeTypeTest$vtype	*vtype;
	_jc_gnu_xml_xpath_NodeTypeTest$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_NodeTypeTest$vtype _jc_gnu_xml_xpath_NodeTypeTest$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_NodeTypeTest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_NodeTypeTest$class_object;

#endif	/* _JC_gnu_xml_xpath_NodeTypeTest_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/NodeTypeTest.h <==
// public final class gnu.xml.xpath.NodeTypeTest

// class file dependencies
// @dep_class 13066c0bc3c76e17 gnu_xml_xpath_NodeTypeTest
// @dep_class d99963ba20fa6197 gnu_xml_xpath_Test
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Test

#include "gnu/xml/xpath/Test.h"

#ifndef _JC_gnu_xml_xpath_NodeTypeTest_H_
#define _JC_gnu_xml_xpath_NodeTypeTest_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Test$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_NodeTypeTest$sub_refs	_jc_gnu_xml_xpath_NodeTypeTest$sub_refs;
typedef struct _jc_gnu_xml_xpath_NodeTypeTest$sub_nonrefs	_jc_gnu_xml_xpath_NodeTypeTest$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_NodeTypeTest$refs	_jc_gnu_xml_xpath_NodeTypeTest$refs;
typedef struct _jc_gnu_xml_xpath_NodeTypeTest$nonrefs	_jc_gnu_xml_xpath_NodeTypeTest$nonrefs;
typedef struct _jc_gnu_xml_xpath_NodeTypeTest$object	_jc_gnu_xml_xpath_NodeTypeTest$object;

typedef const struct _jc_gnu_xml_xpath_NodeTypeTest$vmethods	_jc_gnu_xml_xpath_NodeTypeTest$vmethods;
typedef const struct _jc_gnu_xml_xpath_NodeTypeTest$vtable	_jc_gnu_xml_xpath_NodeTypeTest$vtable;
typedef const struct _jc_gnu_xml_xpath_NodeTypeTest$vtype	_jc_gnu_xml_xpath_NodeTypeTest$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_NodeTypeTest$method$_init$919dbf5c26f3754c(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *, jshort) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_xpath_NodeTypeTest$method$_init$f5cdf9de5128930c(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *, jshort, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Test$object *_jc_gnu_xml_xpath_NodeTypeTest$method$clone$73a8d2a4d673dd95(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_NodeTypeTest$method$getData$bbc608c204d64215(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *) _JC_JCNI_ATTR;
extern jshort _jc_gnu_xml_xpath_NodeTypeTest$method$getNodeType$130bb679261c54d5(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_xpath_NodeTypeTest$method$matches$528a77e426fd27f8(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_NodeTypeTest$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_NodeTypeTest$method_info$clone$73a8d2a4d673dd95;
extern _jc_method _jc_gnu_xml_xpath_NodeTypeTest$method_info$getData$bbc608c204d64215;
extern _jc_method _jc_gnu_xml_xpath_NodeTypeTest$method_info$getNodeType$130bb679261c54d5;
extern _jc_method _jc_gnu_xml_xpath_NodeTypeTest$method_info$matches$528a77e426fd27f8;
extern _jc_method _jc_gnu_xml_xpath_NodeTypeTest$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_NodeTypeTest$vmethods {
	struct _jc_gnu_xml_xpath_Test$object	*(*clone$73a8d2a4d673dd95)(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getData$bbc608c204d64215)(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *) _JC_JCNI_ATTR;
	jshort	(*getNodeType$130bb679261c54d5)(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *) _JC_JCNI_ATTR;
	jboolean	(*matches$528a77e426fd27f8)(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_NodeTypeTest$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_NodeTypeTest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Test$vmethods	gnu_xml_xpath_Test;
	_jc_gnu_xml_xpath_NodeTypeTest$vmethods	gnu_xml_xpath_NodeTypeTest;
};

// Vtype
struct _jc_gnu_xml_xpath_NodeTypeTest$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_NodeTypeTest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_NodeTypeTest$sub_refs {
	struct _jc_java_lang_String$object	*data;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_NodeTypeTest$refs {
    _jc_gnu_xml_xpath_NodeTypeTest$sub_refs	gnu_xml_xpath_NodeTypeTest;
    _jc_gnu_xml_xpath_Test$sub_refs	gnu_xml_xpath_Test;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_NodeTypeTest$sub_nonrefs {
	jshort	type;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_NodeTypeTest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Test$sub_nonrefs	gnu_xml_xpath_Test;
    _jc_gnu_xml_xpath_NodeTypeTest$sub_nonrefs	gnu_xml_xpath_NodeTypeTest;
};

// Object instance structure
struct _jc_gnu_xml_xpath_NodeTypeTest$object {
	_jc_gnu_xml_xpath_NodeTypeTest$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_NodeTypeTest$vtype	*vtype;
	_jc_gnu_xml_xpath_NodeTypeTest$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_NodeTypeTest$vtype _jc_gnu_xml_xpath_NodeTypeTest$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_NodeTypeTest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_NodeTypeTest$class_object;

#endif	/* _JC_gnu_xml_xpath_NodeTypeTest_H_ */
